@@ -1,9 +1,7 @@
 library(pedprobr)
 
-skip("Await next version")
-
-#if(!checkMerlin())
-#  skip("Merlin not installed")
+if(!checkMerlin())
+  skip("Merlin not installed")
 
 test_that("kinshipLR() works with two linked markers", {
   x = linearPed(2)
